@@ -57,8 +57,8 @@ class CorsPlugin:
     def __call__(self, handler):
         def wrapped_handler(*args, **kwargs):
             response.headers['Access-Control-Allow-Origin'] = self._origins
-            response.headers['Access-Control-Allow-Methods'] = 'GET, POST, PUT, OPTIONS'
-            response.headers['Access-Control-Allow-Headers'] = 'Origin, Accept, Content-Type, X-Requested-With, X-api-key'
+            response.headers['Access-Control-Allow-Methods'] = 'GET, POST, PUT, DELETE, OPTIONS'
+            response.headers['Access-Control-Allow-Headers'] = 'Origin, Accept, Content-Type, X-Requested-With, Authorization, X-api-key'
             if request.method != OPTIONS:
                 return handler(*args, **kwargs)
         return wrapped_handler
